@@ -31,6 +31,10 @@
  *   Alejandro Garcia <alex@igalia.com>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <math.h>
 #include <string.h>
 
